@@ -86,6 +86,12 @@ enum {
 	NFTNL_OBJ_LIMIT_FLAGS,
 };
 
+enum {
+	NFTNL_OBJ_SYNPROXY_MSS	= NFTNL_OBJ_BASE,
+	NFTNL_OBJ_SYNPROXY_WSCALE,
+	NFTNL_OBJ_SYNPROXY_FLAGS,
+};
+
 enum {
 	NFTNL_OBJ_TUNNEL_ID	= NFTNL_OBJ_BASE,
 	NFTNL_OBJ_TUNNEL_IPV4_SRC,
@@ -118,7 +124,7 @@ bool nftnl_obj_is_set(const struct nftnl_obj *ne, uint16_t attr);
 void nftnl_obj_unset(struct nftnl_obj *ne, uint16_t attr);
 void nftnl_obj_set_data(struct nftnl_obj *ne, uint16_t attr, const void *data,
 			uint32_t data_len);
-void nftnl_obj_set(struct nftnl_obj *ne, uint16_t attr, const void *data);
+void nftnl_obj_set(struct nftnl_obj *ne, uint16_t attr, const void *data) __attribute__((deprecated));
 void nftnl_obj_set_u8(struct nftnl_obj *ne, uint16_t attr, uint8_t val);
 void nftnl_obj_set_u16(struct nftnl_obj *ne, uint16_t attr, uint16_t val);
 void nftnl_obj_set_u32(struct nftnl_obj *ne, uint16_t attr, uint32_t val);
@@ -161,7 +167,7 @@ struct nftnl_obj_list_iter *nftnl_obj_list_iter_create(struct nftnl_obj_list *l)
 struct nftnl_obj *nftnl_obj_list_iter_next(struct nftnl_obj_list_iter *iter);
 void nftnl_obj_list_iter_destroy(struct nftnl_obj_list_iter *iter);
 
-#ifdef __cplusplusg
+#ifdef __cplusplus
 } /* extern "C" */
 #endif
 
